#!/usr/bin/env python
from pikepdf import Pdf
import shutil

def unlock(pdf_input, pdf_output = None, stdin_password = None, backup = None, pdf_password=""):
  dst = Pdf.new()
  password = pdf_password
  output = "output.pdf"
  if backup:
    output = pdf_input
    new_input = f"{pdf_input}.bak"
    shutil.move(pdf_input, new_input)
    pdf_input = new_input
  if pdf_output:
    output = pdf_output
  if stdin_password:
    password = input("Warning, the password is visible if it is typed\nPassword: ")
  with Pdf.open(pdf_input, password=password) as pdf:
    for page in pdf.pages:
      dst.pages.append(page)
    dst.save(output)




#!/usr/bin/env python
from . import unlock
import argparse

def main():
  example_text = (
    'examples:\n\n'
    '%(prog)s input.pdf -o output.pdf\n'
    '%(prog)s input.pdf -o output.pdf --password 1234\n'
    '%(prog)s input.pdf -o output.pdf --stdin-password\n'
    'echo 1234 | %(prog)s input.pdf -o output.pdf --stdin-password\n'
    '%(prog)s input.pdf -b\n'
  )
  parser = argparse.ArgumentParser(
    description="A simple script that converts PDFs to versions without permission restrictions",
    epilog=example_text,
    formatter_class=argparse.RawDescriptionHelpFormatter
  )
  parser.add_argument("input", help="input PDF file")
  parser.add_argument("-p", "--password", help="password for the input PDF file", default="")
  parser.add_argument("--stdin-password", help="read password from stdin (this will override the --password or -p argument)", action="store_true")
  parser.add_argument("-o", "--output", help="output PDF file, default: output.pdf", default=None)
  parser.add_argument("-b", "--backup", help="the original file will be saved with the extension .bak, and the default output will be the original one", action="store_true")
  args = parser.parse_args()
  unlock(args.input, args.output, args.stdin_password, args.backup, args.password)

if __name__ == "__main__":
  main()



#!/usr/bin/env python
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
  long_description = fh.read()

setup(
  name="pdf-unlocker",
  version="1.3",
  packages=find_packages(),
  entry_points={
    'console_scripts': [
      'pdf-unlocker = pdf_unlocker.__main__:main',
    ],
  },
  url="https://github.com/jfhack/pdf-unlocker",
  install_requires=[
    'pikepdf'
  ],
  long_description=long_description,
  long_description_content_type="text/markdown"
)
